@@ -25,7 +25,7 @@ link_files = {
                 url='https://peps.python.org/pep-{pep_number:0>4}/',
             ),
             dict(
-                pattern=r'(Python #|bpo-)(?P<python>\d+)',
+                pattern=r'(python/cpython#|Python #|bpo-)(?P<python>\d+)',
                 url='http://bugs.python.org/issue{python}',
             ),
         ],
@@ -34,6 +34,7 @@ link_files = {
 
 # Be strict about any broken references
 nitpicky = True
+nitpick_ignore = []
 
 # Include Python intersphinx mapping to prevent failures
 # jaraco/skeleton#51
@@ -46,3 +47,8 @@ intersphinx_mapping = {
 autodoc_preserve_defaults = True
 
 extensions += ['jaraco.tidelift']
+
+nitpick_ignore.extend([
+    ('py:class', 'module'),
+    ('py:class', '_io.BufferedReader'),
+])
